==> Comp2ROC_1.0.tar.gz: Comp2ROC/man/roc.curves.boot.Rd <==
\name{roc.curves.boot}
\alias{roc.curves.boot}
\title{
Compare curves
}
\description{
This is the function which control the whole package.This uses all functions except the reading ones and \code{rocboot.summary} and \code{save.file.summary}.
}
\usage{
roc.curves.boot(data, nb = 1000, alfa = 0.05, name, mod1, mod2)
}
\arguments{
  \item{data}{
Data obtained throught \code{read.file} or \code{read.manually.introduced} }
  \item{nb}{
Number of permutations
}
  \item{alfa}{
Confidance level for parametric methods
}
  \item{name}{
Name too show in graphs}
  \item{mod1}{
Name of Modality 1
}
  \item{mod2}{
Name of Modality 2
}
}

\value{
This function returns a list with:
\item{Area1 }{Area of Curve 1}
\item{SE1 }{Standard error of Curve 1}
\item{Area2 }{Area of Curve 2}
\item{SE2 }{Standard error of Curve 2}
\item{CorrCoef }{Correlation Coeficient}
\item{diff }{Difference Between Areas (TS)}
\item{zstats }{Z Statistic}
\item{pvalue1 }{p-value of Z Statistics}
\item{TrapArea1 }{Area of curve 1 using the Trapezoidal rule}
\item{TrapArea2 }{Area of curve 2 using the Trapezoidal rule}
\item{bootpvalue }{p-value of bootstrapping}
\item{nCross }{Number of Crossings}
\item{ICLB1 }{Confidance Interval: Lower Bound for Curve 1}
\item{ICUB1 }{Confidance Interval: Upper Bound for Curve 1}
\item{ICLB2 }{Confidance Interval: Lower Bound for Curve 2}
\item{ICUB2 }{Confidance Interval: Upper Bound for Curve 2}
\item{ICLBDiff }{Confidance Interval: Lower Bound for Difference between areas}
\item{ICUBDiff }{Confidance Interval: Upper Bound for Difference between areas}
}

\examples{
#data(zhang)
#nameE="new_Zhang"
#moda1="mod1" 
#moda2="mod2"
#data=read.manually.introduced(zhang, moda1, TRUE, moda2, TRUE,  "status", TRUE)
#results=roc.curves.boot(data,name=nameE,mod1= moda1,mod2=moda2) 
}

\keyword{ Permutation }
\keyword{ Comparation }
\keyword{ ROC }
\keyword{ Curves }

==> Comp2ROC_1.1.tar.gz: Comp2ROC/man/roc.curves.boot.Rd <==
\name{roc.curves.boot}
\alias{roc.curves.boot}
\title{Compare curves}

\description{
This is the function which control the whole package.This uses all functions except the reading ones and \code{rocboot.summary} and \code{save.file.summary}.
}
\usage{
roc.curves.boot(data, nb = 1000, alfa = 0.05, name, mod1, mod2, related = TRUE)
}

\arguments{
  \item{data}{
Data obtained throught \code{read.file} or \code{read.manually.introduced}
}

  \item{nb}{
Number of permutations
}
  \item{alfa}{
Confidance level for parametric methods
}
  \item{name}{
Name too show in graphs
}
  \item{mod1}{
Name of Modality 1
}
  \item{mod2}{
Name of Modality 2
}
  \item{related}{
Boolean parameter that represents if the two modalities are related or not
}
}

\value{
This function returns a list with:
\item{Area1 }{Area of Curve 1}
\item{SE1 }{Standard error of Curve 1}
\item{Area2 }{Area of Curve 2}
\item{SE2 }{Standard error of Curve 2}
\item{CorrCoef }{Correlation Coeficient}
\item{diff }{Difference Between Areas (TS)}
\item{zstats }{Z Statistic}
\item{pvalue1 }{p-value of Z Statistics}
\item{TrapArea1 }{Area of curve 1 using the Trapezoidal rule}
\item{TrapArea2 }{Area of curve 2 using the Trapezoidal rule}
\item{bootpvalue }{p-value of bootstrapping}
\item{nCross }{Number of Crossings}
\item{ICLB1 }{Confidance Interval: Lower Bound for Curve 1}
\item{ICUB1 }{Confidance Interval: Upper Bound for Curve 1}
\item{ICLB2 }{Confidance Interval: Lower Bound for Curve 2}
\item{ICUB2 }{Confidance Interval: Upper Bound for Curve 2}
\item{ICLBDiff }{Confidance Interval: Lower Bound for Difference between areas}
\item{ICUBDiff }{Confidance Interval: Upper Bound for Difference between areas}
}

\examples{
#data(zhang)
#nameE="new_Zhang"
#moda1="mod1" 
#moda2="mod2"
#data=read.manually.introduced(zhang, moda1, TRUE, moda2, TRUE,  "status", TRUE)
#results=roc.curves.boot(data,name=nameE,mod1= moda1,mod2=moda2) 
}

\keyword{ Permutation }
\keyword{ Comparation }
\keyword{ ROC }
\keyword{ Curves }
